@@ -21,7 +21,7 @@
 #include <QObject>
 
 class QVariant;
-class JDnsShared;
+class QJDnsShared;
 class AppConfig;
 
 class Worker : public QObject
@@ -35,10 +35,17 @@ public:
 		Stream  // for PUSH/PUB
 	};
 
-	Worker(JDnsShared *dns, AppConfig *config, QObject *parent = 0);
+	enum Format
+	{
+		TnetStringFormat,
+		JsonFormat
+	};
+
+	Worker(QJDnsShared *dns, AppConfig *config, Format format, QObject *parent = 0);
 	~Worker();
 
 	QByteArray rid() const;
+	Format format() const;
 
 	void start(const QVariant &request, Mode mode);
 	void write(const QVariant &request);
